# geotechnicalpy

Academic / Research Open-source python libraries for Geotechnical Engineering 

## Shallow Foundation *(under-development)*

<ol>
<li> Design for Ultimate Limit State
  <ol>
    <li> Estimation of Bearing Capacity </li>
  </ol>
</li>
<li> Design for Serviceability Limit State
  <ol>
    <li> Estimation of Single Pile Settlement 
      <ol>
        <li>Immediate Settlement</i>
        <li>Consolidation Settlement</i>
      </ol>
  </ol>
</li>
</ol>

## Design of Deep Foundations *(under-development)*

### Pile Foundation

<ol>
<li> Static Design Method</li>
<li> Pile Load Test</li>  
<li> Design for Ultimate Limit State
  <ol>
    <li> Estimation of Ultimate Capacity of Piles and Pile Groups </li>
    <li> Negative Skin Friction </li>
  </ol>
</li>
<li> Design for Serviceability Limit State
  <ol>
    <li> Estimation of Single Pile Settlement</li>
    <li> Estimation of Pile Group Settlement </li>
  </ol>
</li>
</ol>

## Pile Raft Foundation *(under-development)*

## Deep Excavation *(under-development)*

## Soil Structure Interaction *(under-development)*

## References
<ol>
<li>Lecture Notes in Professional Master of Structural Design in Tall Buildings (PMTB) at Asian Institute Technology - Thailand </li>
</ol>


Created by:

**Albert Pamonag, M.Eng** <br>
Currently enrolled in Professional Master of Structural Design in Tall Buildings (PMTB) at Asian Institute Technology - Thailand.<br>
Completed in Master of Engineer in Civil Engineer specialization in Structural Engineering at De la Salle University - Manila.<br>
Email: albertpamonag@gmail.com


